==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtbucketHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "uniform partition of attribute range"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "attribute list"
#define KEYC "key attribute based on which a partition is performed (if omitted,  all lines are assumed to take the same key value)"

/*-f*/
#define FLDT "attribute list"
#define FLDC "the attribute whose range is to be partitioned (mandatory: more than one attribute is not allowed)"
#define FLDF NULL

/*-n*/
#define NUMT "number of partitions"
#define NUMC "specify the number of partitions"

/*-F*/
#define FMTT "output format"
#define FMTC "specify the output format of bucket"
#define FMTS "(0: bucket number, 1:range, 2:bucket number+range  (default)"

/*-c*/
#define TYPT "Хåȥ"
#define TYPC "ХåȤοϰϤηꤹ"
#define TYPS "Хå,ϰ϶Хå"

/*-r*/
#define REVT "reverse order"
#define REVC "determine the bucket index so that vaules in the bucket with smaller index are larger than those in the one with the larger index"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS " For those lines such that the value for the attribute specified by -k, the range of the numerical attribute specified by -f is partitioned into a fixed number of subintervals (also called buckets) so that the the number of lines falling into a bucket becomes as uniform as possible. "

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtbucket -f amount,quantity -n 5 -i dat.xt -o rsl.xt\n\
xtbucket -f amount,quantity -n 5 -F 1 -i dat.xt -o rsl.xt\n\
xtbucket -k customerID -f amount,quantity -n 5 -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtagg,xtstatistics,xtshare"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-2.0.1.tar.gz: musashi-core-2.0.1/help/en/xtbucketHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "uniform partition of attribute range"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "attribute list"
#define KEYC "key attribute based on which a partition is performed (if omitted,  all lines are assumed to take the same key value)"

/*-f*/
#define FLDT "attribute list"
#define FLDC "the attribute whose range is to be partitioned (mandatory: more than one attribute is not allowed)"
#define FLDF NULL

/*-n*/
#define NUMT "number of partitions"
#define NUMC "specify the number of partitions"

/*-F*/
#define FMTT "output format"
#define FMTC "specify the output format of bucket"
#define FMTS "(0: bucket number, 1:range, 2:bucket number+range  (default)"

/*-c*/
#define TYPT "bucket type"
#define TYPC "determine the way of bucketing"
#define TYPS "cnt:partition the  numerical attribute into buckets with uniform number of keys, rng:partition the whole range the numerical attribute into equal-sized subintervals"

/*-r*/
#define REVT "reverse order"
#define REVC "determine the bucket index so that vaules in the bucket with smaller index are larger than those in the one with the larger index"

/*-O*/
#define RNGT "ХåϰϽϥե"
#define RNGC "ƹ(-f)γƥХåȤοϰϤϤե̾"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "xtbucket partitions numerical attributes into a fixed number of subintervals (buckets) evenly based on the key attribute. The processing speed increases with the precision of numbers. Decreasing the precision of distinct values by rounding off the decimals and digits in the attribute -f with command xtcal will greatly reduce processing time."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtbucket -f amount,quantity -n 5 -i dat.xt -o rsl.xt\n\
xtbucket -f amount,quantity -n 5 -F 1 -i dat.xt -o rsl.xt\n\
xtbucket -k customerID -f amount,quantity -n 5 -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtagg,xtstatistics,xtshare"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
